;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "mozc" "20251022.236"
  "Minor mode to input Japanese with Mozc."
  '((emacs "24.3"))
  :url "https://github.com/google/mozc"
  :commit "d9c3f195582de6b0baa07ecb81a04e8902acf9af"
  :revdesc "d9c3f195582d"
  :keywords '("mule" "multilingual" "input method"))
